class Param:
  """The Param class defines a configuration parameter.

  Arguments:
    name: A string defining the parameter name
    arg_type: A class object such ``str``, ``int``, ``bool`` or any custom class. This parameter must **not** be a string but a *class* object.
    required: A boolean defining wether the parameter is mandatory or not.
    secret: A boolean defining if the value of the parameter should be secret. If ``secret`` is True, the value of the parameter will not appear in the log.

  Returns:
    ``laboro.config.params.Param``: The Laboro configuration ``Param`` object.

  ..  code-block:: python

      p = Param(name="my_param", arg_type=str, required=True, secret=False)
  """

  @property
  def type(self):
    return self._type

  @type.setter
  def type(self, value):
    self._type = value

  @property
  def required(self):
    return self._required

  @required.setter
  def required(self, value):
    if value in ["1", "yes", "true", "True", True]:
      self._required = True
    else:
      self._required = False

  @property
  def secret(self):
    return self._secret

  @secret.setter
  def secret(self, value):
    if value in ["1", "yes", "true", "True", True]:
      self._secret = True
    else:
      self._secret = False

  def __init__(self, name, arg_type, required=False, secret=False):
    self.name = name
    self.type = arg_type
    self.required = required
    self.secret = secret
